pub enum IapSubscriptionId {
PurchaseToken(String),
OriginalTransactionId(u64),
}Variants
PurchaseToken(String)
Identifies an Android Play Store IAP subscription.
OriginalTransactionId(u64)
Identifies an iOS App Store IAP subscription.
Implementations
Sourceimpl IapSubscriptionId
impl IapSubscriptionId
Sourcepub fn merge(
field: &mut Option<IapSubscriptionId>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<IapSubscriptionId>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.